<?php


class NextEmbeddedComment extends ET_Builder_Module
{
    public $slug = 'dnxte_embedded_comment';
    public $vb_support = 'on';

    protected $module_credits = array(
        'module_uri' => 'www.divinext.com',
        'author' => 'Divi Next',
        'author_uri' => 'www.divinext.com',
    );

    public function init(){
        $this->name = esc_html__('Next FB Embedded Comment', 'dnext-divi-next');
        $this->icon_path = plugin_dir_path(__FILE__) . 'icon.svg';

        $this->settings_modal_toggles = array(
            'general'                                 => array(
                'toggles'                             => array(
                    'dnxte_embedded_comment_elements' => esc_html__( 'Comment Elements', 'dnext-divi-next')
                )
            )
        );

    }

    public function get_advanced_fields_config(){
        return array(
            'text'                          => false,
            'fonts'                         => false,
            'borders'                       => array(
                'default'                   => array(
                    'css'                   => array(
                        'main'              => array(
                            'border_radii'  => "%%order_class%% .fb-comment-embed",
                            'border_styles' => "%%order_class%% .fb-comment-embed",
                        ),
                        'important'         => 'all'
                    ),
                ),
            ),
            'box_shadow'                    => array(
                'default'                   => array(
                    'css'                   => array(
                        'main'              => '%%order_class%% .fb-comment-embed',
                        'custom_style'      => true,
                    ),
                    'default_on_fronts'     => array(
                        'color'             => '',
                        'position'          => '',
                    ),
                ),
            )
        );
    }

    public function get_fields() {
        return array(
            'dnxte_embed_comment_url'   => array(
                'label'                 => esc_html__('Comment URL', 'dnext-divi-next'),
                'type'                  => 'text',
                'option_category'       => 'basic_option',
                'description'           => esc_html__('Input Comment URL', 'dnext-divi-next'),
                'toggle_slug'           => 'dnxte_embedded_comment_elements',
                'dynamic_content'       => 'text',
            ),
            'dnxte_embed_comment_parent'=> array(
                'label'                 => esc_html__('Show Parent Comment', 'dnext-divi-next'),
                'type'                  => 'yes_no_button',
                'toggle_slug'           => 'dnxte_embedded_comment_elements',
                'options'               => array(
                    'on'                => esc_html__('Yes', 'dnext-divi-next'),
                    'off'               => esc_html__('No', 'dnext-divi-next'),
                ),
                'default_on_front'      => 'off',
            ),
            'dnxte_embed_comment_lazy'  => array(
                'label'                 => esc_html__('Lazy Loading', 'dnext-divi-next'),
                'type'                  => 'yes_no_button',
                'toggle_slug'           => 'dnxte_embedded_comment_elements',
                'options'               => array(
                    'on'                => esc_html__('Yes', 'dnext-divi-next'),
                    'off'               => esc_html__('No', 'dnext-divi-next'),
                ),
                'default_on_front'      => 'off',
            ),
            'dnxte_embed_comment_width' => array(
                'label'                 => esc_html__('Width', 'dnext-divi-next'),
                'type'                  => 'range',
                'option_category'       => 'basic_option',
                'range_settings'        => array(
                    'step'              => 1,
                    'min'               => 1,
                    'max'               => 1000,
                ),
                'default'               => '550',
                'fixed_unit'            => '',
                'validate_unit'         => false,
                'unitless'              => true,
                'toggle_slug'           => 'dnxte_embedded_comment_elements',
                'computed_affects'      => array(
					'__embeddedcomment',
				),
            ),
            '__embeddedcomment' => array(
				'type'                  => 'computed',
				'computed_callback'     => array( 'NextEmbeddedComment' ),
				'computed_depends_on'   => array(
					'dnxte_embed_comment_width'
				),
			),
        );
    }

    public function render($attrs, $content = null, $render_slug){
        if(!$this->props['border_style_all']){
            ET_Builder_Element::set_style($render_slug, array(
                'selector' => "%%order_class%% .fb-comment-embed",
                'declaration' => sprintf('border-style: solid !important;'),
            ));
        }

        $show_parent = "on" === $this->props['dnxte_embed_comment_parent'];
        $loading_lazy = "on" === $this->props['dnxte_embed_comment_lazy'];

            
        return sprintf('
            <div class="fb-comment-embed"
                data-href="%1$s"
                data-include-parent="%2$s" data-lazy="%3$s" data-width="%4$s"></div>
                <div id="fb-root"></div>',
                    $this->props['dnxte_embed_comment_url'],
                    $show_parent,
                    $loading_lazy,
                    $this->props['dnxte_embed_comment_width']
            );
        }

}

new NextEmbeddedComment;