<?php

class Next_Rating extends ET_Builder_Module
{

    public $slug = 'dnxte_rating';
    public $vb_support = 'on';

    protected $module_credits = array(
        'module_uri' => 'www.divinext.com',
        'author' => 'Divi Next',
        'author_uri' => 'www.divinext.com',
    );

    public function init()
    {
        $this->name = esc_html__('Next Rating', 'dnext-divi-next');
        $this->icon_path = plugin_dir_path(__FILE__) . 'icon.svg';

        $this->settings_modal_toggles = array(
            'general' => array(
                'toggles' => array(
                    'next_rating' => array(
                        'title' => esc_html__('Rating', 'dnext-divi-next'),
                    ),
                ),
            ),
            'advanced' => array(
                'toggles' => array(
                    'rating_settings' => array(
                        'title' => esc_html__('Rating Settings', 'dnext-divi-next'),
                    ),
                ),
            ),
            'custom_css' => array(
                'toggles' => array(),
            ),
        );

        $this->advanced_fields = array(
            'fonts' => false,
            'text' => false,
        );

        // Custom CSS Field
        $this->custom_css_fields = array(

            'review_rating_wrapper' => array(
                'label' => esc_html__('Rating', 'dnext-divi-next'),
                'selector' => '%%order_class%% .dnxte-review-social',
            ),
        );
    }

    public function get_fields()
    {
        $fields = array(
            'star_rating' => array(
                'label' => esc_html__('Rating', 'dnext-divi-next'),
                'description' => esc_html__('Adjust the rating of the review.', 'dnext-divi-next'),
                'type' => 'range',
                'option_category' => 'basic_option',
                'toggle_slug' => 'next_rating',
                'allowed_units' => array('%', 'em', 'rem', 'px', 'cm', 'mm', 'in', 'pt', 'pc', 'ex', 'vh', 'vw'),
                'default' => '5',
                'fixed_unit' => '',
                'validate_unit' => false,
                'unitless' => true,
                'default_on_front' => '5',
                'allow_empty' => true,
                'range_settings' => array(
                    'min' => '0',
                    'max' => '10',
                    'step' => '0.1',
                ),
                'mobile_options' => true,
                'hover' => 'tabs',
            ),
            'star_scale' => array(
                'label' => esc_html__('Rating Scale', 'dnext-divi-next'),
                'description' => esc_html__('Choose your rating scale', 'dnext-divi-next'),
                'type' => 'select',
                'option_category' => 'layout',
                'toggle_slug' => 'next_rating',
                'options' => array(
                    '5' => esc_html__('0 - 5', 'dnext-divi-next'),
                    '10' => esc_html__('0 - 10', 'dnext-divi-next'),
                ),
                'default' => '5',
            ),
            'star_rating_alignment'    => array(
                'label'           => esc_html__('Rating Alignment', 'dnext-divi-next'),
                'description'     => esc_html__('Align rating to the left, right or center.', 'dnext-divi-next'),
                'type'            => 'align',
                'option_category' => 'layout',
                'options'         => et_builder_get_text_orientation_options(array('justified')),
                'tab_slug'        => 'advanced',
                'toggle_slug'     => 'rating_settings',
                'mobile_options'  => true,
            ),
            'rating_color' => array(
                'label' => esc_html__('Select Star Color', 'dnext-divi-next'),
                'type' => 'color-alpha',
                'tab_slug' => 'advanced',
                'toggle_slug' => 'rating_settings',
                'hover' => 'tabs',
                'default' => '#ffbf36',
            ),
            'star_size' => array(
                'label' => esc_html__('Size', 'dnext-divi-next'),
                'description' => esc_html__('Control the size of the star by increasing or decreasing the font size.', 'dnext-divi-next'),
                'type' => 'range',
                'option_category' => 'layout',
                'tab_slug' => 'advanced',
                'toggle_slug' => 'rating_settings',
                'allowed_units' => array('%', 'em', 'rem', 'px', 'cm', 'mm', 'in', 'pt', 'pc', 'ex', 'vh', 'vw'),
                'default' => '16px',
                'default_unit' => 'px',
                'default_on_front' => '',
                'range_settings' => array(
                    'min' => '1',
                    'max' => '120',
                    'step' => '1',
                ),
                'mobile_options' => true,
                'hover' => 'tabs',
            ),
        );

        return $fields;
    }

    public function get_rating()
    {
        $rating_scale = (int) $this->props['star_scale'];
        $rating = (float) $this->props['star_rating'] > $rating_scale ? $rating_scale : $this->props['star_rating'];

        return array($rating, $rating_scale);
    }

    /**
     * Print the actual stars and calculate their filling.
     *
     * Rating type is float to allow stars-count to be a fraction.
     * Floored-rating type is int, to represent the rounded-down stars count.
     * In the `for` loop, the index type is float to allow comparing with the rating value.
     *
     */
    public function render_stars()
    {
        $rating_data = $this->get_rating();
        $rating = (float) $rating_data[0];
        $floored_rating = floor($rating);
        $star_html = '';

        for ($stars = 1.0; $stars <= $rating_data[1]; $stars++) {
            if ($stars <= $floored_rating) {
                $star_html .= '<i class="divinext-star-full et-pb-icon"></i>';
            } else if ($floored_rating + 1 === $stars && $rating !== $floored_rating) {
                $star_html .= '<i class="divinext-star-' . ($rating - $floored_rating) * 10 . ' et-pb-icon"></i>';
            } else {
                $star_html .= '<i class="divinext-star-empty et-pb-icon"></i>';
            }
        }

        return $star_html;
    }

    /**
     * Get Rating alignment.
     *
     * @since 3.23 Add responsive support by adding device parameter.
     *
     * @param  string $device Current device name.
     * @return string Alignment value, rtl or not.
     */

    public function get_star_rating_alignment($device = 'desktop') {
        $suffix = 'desktop' !== $device ? "_{$device}" : '';
        $text_orientation = isset($this->props["star_rating_alignment{$suffix}"]) ? $this->props["star_rating_alignment{$suffix}"] : '';

        return et_pb_get_alignment($text_orientation);
    }

    public function render($attrs, $content = null, $render_slug)
    {

        $multi_view = et_pb_multi_view_options($this);
        // Star Rating Alignment.
        $star_rating_alignment               = $this->get_star_rating_alignment();
        $is_star_rating_alignment_responsive = et_pb_responsive_options()->is_responsive_enabled($this->props, 'star_rating_alignment');
        $star_rating_alignment_tablet        = $is_star_rating_alignment_responsive ? $this->get_star_rating_alignment('tablet') : '';
        $star_rating_alignment_phone         = $is_star_rating_alignment_responsive ? $this->get_star_rating_alignment('phone') : '';
        
        $star_rating_alignments = array();
        if (!empty($star_rating_alignment)) {
            array_push($star_rating_alignments, sprintf('dnext_star_rating_alignment_%1$s', esc_attr($star_rating_alignment)));
        }

        if (!empty($star_rating_alignment_tablet)) {
            array_push($star_rating_alignments, sprintf('dnext_star_rating_alignment_tablet_%1$s', esc_attr($star_rating_alignment_tablet)));
        }

        if (!empty($star_rating_alignment_phone )) {
            array_push($star_rating_alignments, sprintf('dnext_star_rating_alignment_phone_%1$s', esc_attr($star_rating_alignment_phone)));
        }

        $star_rating_alignment_classes = join(' ', $star_rating_alignments);

        $stars_output = '<div class="dnxte-review-social dnext-star-rating">' . $this->render_stars() . '</div> ';

        // Number Star Size
        $star_size = $this->props['star_size'];
        $star_size_values = et_pb_responsive_options()->get_property_values($this->props, 'star_size');
        $star_size_tablet = isset($star_size_values['tablet']) ? $star_size_values['tablet'] : '';
        $star_size_phone = isset($star_size_values['phone']) ? $star_size_values['phone'] : '';

        // Size
        if ('' !== $star_size) {
            $star_size_style = sprintf('font-size: %1$s !important;', esc_attr($star_size));
            $star_size_tablet_style = '' !== $star_size_tablet ? sprintf('font-size: %1$s !important;', esc_attr($star_size_tablet)) : '';
            $star_size_phone_style = '' !== $star_size_phone ? sprintf('font-size: %1$s !important;', esc_attr($star_size_phone)) : '';

            ET_Builder_Element::set_style($render_slug, array(
                'selector' => "%%order_class%% .dnext-star-rating .et-pb-icon",
                'declaration' => $star_size_style,
            ));

            ET_Builder_Element::set_style($render_slug, array(
                'selector' => "%%order_class%% .dnext-star-rating .et-pb-icon",
                'declaration' => $star_size_tablet_style,
                'media_query' => ET_Builder_Element::get_media_query('max_width_980'),
            ));

            ET_Builder_Element::set_style($render_slug, array(
                'selector' => "%%order_class%% .dnext-star-rating .et-pb-icon",
                'declaration' => $star_size_phone_style,
                'media_query' => ET_Builder_Element::get_media_query('max_width_767'),
            ));
        }

        $oder_class = '%%order_class%% .dnext-star-rating i.divinext-star-full::before, %%order_class%% .dnext-star-rating i.divinext-star-1:before, %%order_class%% .dnext-star-rating i.divinext-star-2:before, %%order_class%% .dnext-star-rating i.divinext-star-3:before, %%order_class%% .dnext-star-rating i.divinext-star-4:before, %%order_class%% .dnext-star-rating i.divinext-star-5:before, %%order_class%% .dnext-star-rating i.divinext-star-6:before, %%order_class%% .dnext-star-rating i.divinext-star-7:before, %%order_class%% .dnext-star-rating i.divinext-star-8:before, %%order_class%% .dnext-star-rating i.divinext-star-9:before, %%order_class%% .dnext-star-rating i.divinext-star-10:before';
        // Star Color
        $rating_color_values = et_pb_responsive_options()->get_property_values($this->props, 'rating_color');
        et_pb_responsive_options()->generate_responsive_css($rating_color_values, $oder_class, 'color', $render_slug, '', 'color');

        return sprintf(
            '<div class="dnxte-star-wrapper %2$s">
				%1$s
			</div>',
            $stars_output,
            esc_attr( $star_rating_alignment_classes )
        );
    }
}

new Next_Rating;
